@@ -48,6 +48,8 @@ class Resources:
     Plugins = 12
     ## Location of data regarding bundled packages
     BundledPackages = 13
+    ## Location of text files
+    Texts = 14
 
     ## Any custom resource types should be greater than this to prevent collisions with standard types.
     UserType = 128
@@ -503,6 +505,8 @@ class Resources:
             # if the dest_path exist, it needs to be removed first
             if not os.path.exists(dest_path):
                 shutil.move(temp_dir_path, dest_path)
+            else:
+                Logger.log("e", "Unable to copy files to %s as the folder already exists", dest_path)
         except:
             Logger.log("e", "Something occurred when copying the version folder from '%s' to '%s'", src_path, dest_path)
 
@@ -589,6 +593,7 @@ class Resources:
         ContainerStacks: "stacks",
         Plugins: "plugins",
         BundledPackages: "bundled_packages",
+        Texts: "texts",
     } #type: Dict[int, str]
     __types_storage = {
         Resources: "",
