@@ -222,7 +222,7 @@ class ContainerRegistry(ContainerRegistryInterface):
                     Logger.log("w", "Metadata of container {container_id} is missing even though the container is added during run-time.")
                     return []
                 metadata = provider.loadMetadata(kwargs["id"])
-                if metadata is None or metadata["id"] in self._wrong_container_ids:
+                if metadata is None or metadata.get("id", "") in self._wrong_container_ids or "id" not in metadata:
                     return []
                 self.metadata[metadata["id"]] = metadata
                 self.source_provider[metadata["id"]] = provider
@@ -321,6 +321,7 @@ class ContainerRegistry(ContainerRegistryInterface):
     ##  Load the metadata of all available definition containers, instance
     #   containers and container stacks.
     def loadAllMetadata(self) -> None:
+        self._clearQueryCache()
         gc.disable()
         resource_start_time = time.time()
         for provider in self._providers:  # Automatically sorted by the priority queue.
