@@ -1,7 +1,7 @@
 # Copyright (c) 2018 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
 
-from typing import Any, Dict, List, Optional, TYPE_CHECKING
+from typing import Any, Dict, List, Optional, Set, TYPE_CHECKING
 
 import UM.Decorators
 from UM.Logger import Logger
@@ -11,12 +11,17 @@ from UM.Settings.PropertyEvaluationContext import PropertyEvaluationContext
 if TYPE_CHECKING:
     from UM.Application import Application
     from UM.Settings.InstanceContainer import InstanceContainer
-    from UM.Settings.SettingDefinition import SettingDefinition #For typing.
+    from UM.Settings.SettingDefinition import SettingDefinition
+
 
 ##  Shared interface between setting container types
 #
 @UM.Decorators.interface
 class ContainerInterface:
+
+    def __init__(self, *args, **kwargs):
+        pass
+
     ##  Get the ID of the container.
     #
     #   The ID should be unique, machine readable and machine writable. It is
@@ -72,6 +77,11 @@ class ContainerInterface:
     def hasProperty(self, key: str, property_name: str) -> bool:
         pass
 
+    ##  Get all the setting keys known to this container.
+    #   \return Set of keys.
+    def getAllKeys(self) -> Set[str]:
+        pass
+
     ##  Serialize this container to a string.
     #
     #   The serialized representation of the container can be used to write the
@@ -159,6 +169,7 @@ class ContainerInterface:
     metaDataChanged = None  # type: Signal
 
 
+@UM.Decorators.interface
 class DefinitionContainerInterface(ContainerInterface):
     def findDefinitions(self, **kwargs: Any) -> List["SettingDefinition"]:
         raise NotImplementedError()
